==> de.bsvrz.buv.plugin.dobj.source_4.0.0.201905071350.jar: de/bsvrz/buv/plugin/dobj/kollision/travers/NullPunktTraverser.java <==
/*
 * Rahmenwerk-Plug-in "Darstellungsobjekte"
 * Copyright (C) 2018 BitCtrl Systems GmbH
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 3 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 51
 * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weissenfelser Strasse 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.buv.plugin.dobj.kollision.travers;

import java.util.Iterator;

import org.eclipse.draw2d.geometry.Point;

/**
 * Traversiert nur einen Punkt (0, 0).
 *
 * @author BitCtrl Systems GmbH, thierfelder
 *
 */
public class NullPunktTraverser implements IPunktTraverser {

	private static final Point NULL_PUNKT = new Point(0, 0);

	private int index;

	@Override
	public Iterator<Point> iterator() {
		return new Iterator<Point>() {

			@Override
			public boolean hasNext() {
				return index == 0;
			}

			@Override
			public Point next() {
				index++;
				return NULL_PUNKT;
			}

			@Override
			public void remove() {
				//
			}

		};
	}

}

==> de.bsvrz.buv.plugin.dobj.source_4.5.0.202510170820.jar: de/bsvrz/buv/plugin/dobj/kollision/travers/NullPunktTraverser.java <==
/*
 * Rahmenwerk-Plug-in "Darstellungsobjekte"
 * Copyright (C) 2023 BitCtrl Systems GmbH
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 3 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 51
 * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weissenfelser Strasse 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.buv.plugin.dobj.kollision.travers;

import java.util.Iterator;

import org.eclipse.draw2d.geometry.Point;

/**
 * Traversiert nur einen Punkt (0, 0).
 *
 * @author BitCtrl Systems GmbH, thierfelder
 *
 */
public class NullPunktTraverser implements IPunktTraverser {

	private static final Point NULL_PUNKT = new Point(0, 0);

	private int index;

	@Override
	public Iterator<Point> iterator() {
		return new Iterator<>() {

			@Override
			public boolean hasNext() {
				return index == 0;
			}

			@Override
			public Point next() {
				index++;
				return NULL_PUNKT;
			}

			@Override
			public void remove() {
				//
			}

		};
	}

}
